@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::Role::Runner;
 
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 
 use Moose::Role;
 use namespace::autoclean;
@@ -215,15 +215,21 @@ sub _eval_cmd {
     $code = $self->build_formatter($params)->format($code);
     $self->${ $self->quiet ? \'log_debug' : \'log' }("evaluating: $code");
 
-    my $sub = sub { eval $code };
+    my $sub = __eval_wrapper($code);
     $sub->($self);
+    my $error = $@;
 
-    if ($@) {
+    if (defined $error and $error ne '') {
         $self->${ $self->fatal_errors ? \'log_fatal' : $self->quiet ? \'log_debug' : \'log'}
-            ('evaluation died: ' . $@);
+            ('evaluation died: ' . $error);
     }
 }
 
+sub __eval_wrapper {
+    my $code = shift;
+    sub { eval $code };
+}
+
 around mvp_multivalue_args => sub {
     my ($original, $self) = @_;
 
@@ -287,4 +293,4 @@ sub build_formatter {
 sub current_perl_path { $^X }
 
 1;
-# vim: set ts=4 sts=4 sw=4 expandtab smarttab:
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
